/*
Requires Microsoft Platform SDK Headers to compile (windows.h)
Requires kernel32.lib and user32.lib to link properly
*/

#ifndef _WIN32_WINNT		                 
#define _WIN32_WINNT 0x0501	
#endif						

#include <windows.h>
#include <stdio.h>
#include <tchar.h>

HHOOK g_hMouseHook;

// Returns the current console HWND
// Code provided by Microsoft
// http://support.microsoft.com/kb/124103

HWND GetConsoleHwnd(void) {
   #define MY_BUFSIZE 1024 // Buffer size for console window titles.
   HWND hwndFound;         // This is what is returned to the caller.
   char pszNewWindowTitle[MY_BUFSIZE]; // Contains fabricated WindowTitle
   char pszOldWindowTitle[MY_BUFSIZE]; // Contains original WindowTitle
   // Fetch current window title.
   GetConsoleTitle(pszOldWindowTitle, MY_BUFSIZE);
   // Format a "unique" NewWindowTitle.
   wsprintf(pszNewWindowTitle,"%d/%d", GetTickCount(), GetCurrentProcessId());
   // Change current window title.
   SetConsoleTitle(pszNewWindowTitle);
   // Ensure window title has been updated.
   // changed this to something higher as very busy machines might not
   // respond within the original 40 ms
   Sleep(500);
   // Look for NewWindowTitle.
   hwndFound=FindWindow(NULL, pszNewWindowTitle);
   // Restore original window title.
   SetConsoleTitle(pszOldWindowTitle);
   return(hwndFound);
}

LRESULT CALLBACK LowLevelMouseProc(int nCode, WPARAM wParam, LPARAM lParam) {
	switch (wParam) {
		case WM_MBUTTONDOWN:
		case WM_MBUTTONUP:
		case WM_RBUTTONDOWN:
		case WM_RBUTTONUP:
			// dismiss these events
			return 1;
		default:
			// let all other events pass through
			return CallNextHookEx(g_hMouseHook, nCode, wParam, lParam);
	}
}

int _tmain(int argc, _TCHAR* argv[]) {
	// Hide the console window the application was launched
	ShowWindow(GetConsoleHwnd(), SW_HIDE);
	// This will contain the messages
	MSG msg;
	// set handle for the hook
	g_hMouseHook = SetWindowsHookEx( WH_MOUSE_LL, LowLevelMouseProc, GetModuleHandle(NULL), 0 );
	// bail if something went wrong
	if (!g_hMouseHook) 
		return 1;
	// fetch the messages and handle them
	while ( GetMessage(&msg, NULL, 0, 0) ) {
	        TranslateMessage(&msg);
	        DispatchMessage(&msg);
	}
	// release the hook
	UnhookWindowsHookEx(g_hMouseHook);
	return (int) msg.wParam;
}

